@@ -31,9 +31,9 @@ class SimpleMemberSystem:
         account, pws = self.__hash_login_info__(account, pws)
         self.__set_new_user__(account, pws)
 
-    def login_user(self, label, account, pws):
+    def login_user(self, label, account, pws, encode=True):
         account, pws = self.__hash_login_info__(account, pws)
-        return self.__get_user_by_account_and_pws__(label, account, pws)
+        return self.__get_user_by_account_and_pws__(label, account, pws, encode)
 
     def update_user(self, account, pws, **kwargs):
         account, pws = self.__hash_login_info__(account, pws)
@@ -66,7 +66,7 @@ class SimpleMemberSystem:
             "uuid": str(uuid.uuid4())
         }
         self.JDB_user.__insert__(key=account, value=data,
-                                                  e=RuntimeError(f"the account is exist.: {account}"))
+                                 e=RuntimeError(f"the account is exist.: {account}"))
 
     def __set_user_info__(self, account, pws, **kwargs):
         source_info = self.__get_user_by_account_and_pws__(label=None, account=account, pws=pws, encode=False)
@@ -95,4 +95,4 @@ class SimpleMemberSystem:
 
     def __del_user_by_account_and_pws__(self, account, pws):
         _ = self.__get_user_by_account_and_pws__(label=None, account=account, pws=pws, encode=False)
-        self.JDB_user.__remove__(account)
\ No newline at end of file
+        self.JDB_user.__remove__(account)
